import sys, os
import numpy as np
import BioNetInput, BioNetTrajectory

#
# Data
#

# Constants
numNodes = 10000
radius = 2.5
mu = 1
kbt = 4.11

# Variables
vfs = [0.005, 0.01, 0.05, 0.07, 0.1]
ns = [4,6,8,14]
rates = [1000]

numRuns = 3
radius = 1.0
# Loop over variables (including numRuns)
for rate in rates:

	for s in ns:

		for vf in vfs:

			# Get initial script
			iFname = "../input/N%dSites%02dRadius%05.2fRate%5.2fvf%0.4fRelax.xml" % (numNodes, s, radius, rate, vf)

			inp = BioNetInput.BioNetInput()
			inp.load(iFname)

			# Alter times (5 particles of diffusion)
			drag = 6 * np.pi * mu * radius
			inp.params.simTime = 0.5 * np.power(10 * radius, 2) * drag / kbt
			inp.params.timePerFrame = int(inp.params.simTime / 10.0)
			if inp.params.timePerFrame < inp.params.dt:
				inp.params.timePerFrame = inp.params.dt

			for nr in range(numRuns):

				# Get final trajectory frame
				tFname = "../output/N%dSites%02dRadius%05.2fRate%5.2fvf%0.4fRelaxRun%d.bntrj" % (numNodes, s, radius, rate, vf, nr)

				traj = BioNetTrajectory.BioNetTrajectory()
				traj.loadFinalFrame(tFname, inScript=inp)

				# Modify the input script
				for i in range(inp.numNodes):
					inp.node[i].pos = traj.frame[0].pos[i]
					inp.node[i].orientation = traj.frame[0].euler[i]

				# Write to output
				oFname = "../input/N%dSites%02dRadius%05.2fRate%5.2fvf%0.4fStericRelaxRun%d.xml" % (numNodes, s, radius, rate, vf, nr)
				inp.writeToFile(oFname)
			

